ggdendro-package: Tools for creating dendrograms, regresion tree and classification tree plots using ggplot in [R]
Description
Tools for extracting dendrogram and tree diagram plot
data for use with ggplot.Details
This is a set of tools for dendrograms and tree plots
using ggplot
The ggplot philosophy is to clearly separate data from
the presentation. Unfortunately the plot method for
dendrograms (plot.dendrogram) plots
directly to a plot device without exposing the data. The
ggdendro package resolves this by making available
functions that extract the dendrogram plot data. This
data can be used with ggplot.
dendro_data extracts data from several
cluster algorithms. It is a generic function with
specific implementations for:
These methods create an object of class dendro,
consisting of a list of data.frames. To extract the
relevant data frames from the list, there are three
accessor functions:
{the line segment
data} label {the text for each end
segment} leaf_label {the leaf labels
of a tree diagram}